@@ -13,17 +13,21 @@
 #include <wx/snglinst.h>
 #include <wx/intl.h>
 #include <wx/ipc.h>
+#include "Notifier.h"
+//#include "AgenderIPC.h"
 
 class AgenderApp : public wxApp
 {
 	public:
-		virtual bool OnInit();
-		virtual int OnExit();
+		bool OnInit();
+		int OnRun();
+		int OnExit();
 	private:
 		void OnEndSession(wxCloseEvent& event);
 		wxSingleInstanceChecker* m_checker;
 		wxServer* m_server;
 		wxLocale m_locale;
+		Notifier notif;
 		DECLARE_EVENT_TABLE()
 };
 
