@@ -5,20 +5,20 @@
  * Copyright: Gabriel Espinoza
  * License: GPLv3+
  **************************************************************/
-#include <wx/wxprec.h>
-
 #ifdef __BORLANDC__
     #pragma hdrstop
 #endif
 
-#include "AgenderIPC.h"
-#ifndef WX_PRECOMP
 #include <wx/log.h>
-#include <wx/defs.h>
 #include <wx/window.h>
 #include <wx/app.h>
-#endif
-
+/**
+the next file must be the last we include
+else the others will overide wxUSE_DDE_FOR_IPC
+and cause Agender to crash when calling
+AgenderServer->Create()
+*/
+#include "AgenderIPC.h"
 
 #if defined __WXMSW__ && wxUSE_DDE_FOR_IPC == 0
 #warning not using dde under msw
@@ -49,6 +49,6 @@ wxConnectionBase * AgenderServer::OnAcceptConnection(const wxString& topic)
 {
 	if (topic != IPC_Topic)
 		return NULL;
-	wxLogVerbose(_T("Connection acepted"));
+	wxLogVerbose(_T("IPC Connection acepted"));
 	return new AgenderConnection;
 }
