@@ -6,14 +6,11 @@
  * Copyright: Gabriel Espinoza
  * License: GPLv3+
  **************************************************************/
- #include <wx/wxprec.h>
-
 #ifdef __BORLANDC__
     #pragma hdrstop
     //for those who can't change turboc++, like theacher Nancy
 #endif
 
-#ifndef WX_PRECOMP
 #include <wx/msgdlg.h>
 #include <wx/defs.h>
 #include <wx/settings.h>
@@ -28,26 +25,18 @@
 #include <wx/utils.h>
 #include <wx/log.h>
 #include <wx/filename.h>
-//escribir algunas cosas en el registro
-#ifdef __WXMSW__
-#include <wx/msw/registry.h>
-#endif//__WXMSW__
 #if defined wxHAS_TASK_BAR_ICON
 #include "AgenderTray.h"
 #endif
-#endif
 
 #include "AgenderMain.h"
 #include "AgenderCal.h"
 
-#define __AGENDER_VERSION__ "1.1.7.1"
-
 #ifndef __REVISION__
 #define __REVISION__ 0
 #endif
 
 #include "Agender16x16.xpm"
-#include "Agender.xpm"
 
 //(*IdInit(AgenderFrame)
 const long AgenderFrame::ID_CALENDARCTRL1 = wxNewId();
@@ -55,6 +44,7 @@ const long AgenderFrame::ID_LISTBOX1 = wxNewId();
 const long AgenderFrame::ID_TEXTCTRL1 = wxNewId();
 const long AgenderFrame::ID_BUTTON1 = wxNewId();
 const long AgenderFrame::ID_BUTTON2 = wxNewId();
+const long AgenderFrame::ID_UPDATE_FOUND = wxNewId();
 //*)
 
 BEGIN_EVENT_TABLE(AgenderFrame,wxFrame)
@@ -63,11 +53,11 @@ BEGIN_EVENT_TABLE(AgenderFrame,wxFrame)
 	EVT_MENU(wxID_FIND,AgenderFrame::OnSearch)
 	EVT_MENU(7004,AgenderFrame::OnChangeNotesColour)
 	EVT_MENU(7003,AgenderFrame::OnYearSel)
-	EVT_MENU(7005,AgenderFrame::OnAutoStart)
 	EVT_MENU(ID_RENAME,AgenderFrame::OnMenuRename)
 	EVT_MENU_RANGE(ID_NORMAL,ID_STICKY,AgenderFrame::OnMenuNoteFlag)
 	EVT_ACTIVATE(AgenderFrame::OnActivate)
 	EVT_MENU(wxID_CLOSE,AgenderFrame::OnEscape)
+	EVT_MENU(ID_UPDATE_FOUND,AgenderFrame::OnUpdateFound)
 	//(*EventTable(AgenderFrame)
 	//*)
 END_EVENT_TABLE()
@@ -157,12 +147,13 @@ AgenderFrame::AgenderFrame(wxLocale& locale,wxString cfgFile):m_locale(locale)
 	ChangeSelector();
 	MarkDays();
 	//shortcuts
-	wxAcceleratorEntry entries[3];
+	wxAcceleratorEntry entries[4];
 	entries[0].Set(wxACCEL_CTRL,(int)'f',wxID_FIND);
 	entries[1].Set(wxACCEL_NORMAL,WXK_ESCAPE,wxID_CLOSE);
 	// TODO (virtuoso#1#): use for cut
 	entries[2].Set(wxACCEL_CTRL,(int)'x',wxID_ANY);
-	wxAcceleratorTable accel(3, entries);
+	entries[3].Set(wxACCEL_CTRL,(int)'q',wxID_ANY);
+	wxAcceleratorTable accel(4, entries);
 	this->SetAcceleratorTable(accel);
 	//find dialog
 	fndData = new wxFindReplaceData;
@@ -170,32 +161,11 @@ AgenderFrame::AgenderFrame(wxLocale& locale,wxString cfgFile):m_locale(locale)
 	SearchMode = false;
 	//size
 	SetSize(schdl->Read(_T("/x"),wxDefaultPosition.x),schdl->Read(_T("/y"),wxDefaultPosition.y),
-		  schdl->Read(_T("/w"),wxDefaultSize.x),schdl->Read(_T("/h"),wxDefaultSize.y));
+		schdl->Read(_T("/w"),wxDefaultSize.x),schdl->Read(_T("/h"),wxDefaultSize.y));
 	SetTransparent(schdl->Read(_T("/opacity"),255));
-	//autostart
-	wxCommandEvent event;
-	event.SetId(7005);
-	wxPostEvent(GetEventHandler(),event);
 	//taskbaricon
 #if defined wxHAS_TASK_BAR_ICON
-	//this is a stupid hack, but gnome is a very stupid desktop environment
-#if wxCHECK_VERSION(2,9,0)
-	wxLogVerbose(_T("using dev"));
-#elif defined __X__ || defined __WXGTK__
-	wxArrayString output;
-	wxExecute(_T("pidof gnome-session"),output,wxEXEC_SYNC);
-	if (!output.IsEmpty()) {
-		output.Empty();
-		do
-		{
-			wxExecute(_T("pidof gnome-panel"),output,wxEXEC_SYNC);
-			if (output.IsEmpty())
-				wxSleep(5);
-		} while(output.IsEmpty());
-		wxSleep(4);
-	}
-#endif
-	trayicon = new AgenderTray(this,schdl->Read(_T("/opacity"),255));
+	trayicon = new AgenderTray(this);
 	trayicon->SetIcon(Agender16x16_xpm,_T("Virtuosonic Agender"));
 #endif//wxHAS_TASK_BAR_ICON
 }
@@ -232,7 +202,7 @@ void AgenderFrame::OnClose(wxCloseEvent& WXUNUSED(event))
 void AgenderFrame::OnButton3Click(wxCommandEvent& WXUNUSED(event))
 {
 	wxAboutDialogInfo info;
-	//developer
+	//developer a.k.a. me
 	info.AddDeveloper(_T("Gabriel Espinoza <virtuosonic@users.sourceforge.net>"));
 	//translators
 	info.AddTranslator(_T("Gabriel Espinoza : spanish"));
@@ -246,9 +216,12 @@ void AgenderFrame::OnButton3Click(wxCommandEvent& WXUNUSED(event))
 	info.AddTranslator(_T("Bruno Mace : french"));
 	info.AddTranslator(_T("senoutouya <senoutouya@gmail.com> : chinese"));
 	info.AddTranslator(_T("Adi D. <nevvermind@users.sourceforge.net> : romanian"));
+	info.AddTranslator(_T("Itamar Shoham <itsho@users.sourceforge.net> : hebrew"));
+	//sound
+	//info.AddArtist(_T("xyzr_kx from Freesound Project: alarm_clock.wav"));
 	//etc
-	info.SetDescription(wxString::Format(_T("%s\n%s %s %s %s %i"),_("A cross-platform schedule tool"),
-							 _("Build:"),__TDATE__,__TTIME__,_("From: svn"),__REVISION__));
+	info.SetDescription(wxString::Format(_T("%s\n%s %s %s\n%s %i"),_("A cross-platform schedule tool"),
+							 _("Build:"),__TDATE__,__TTIME__,_("Revision:"),__REVISION__));
 	info.SetWebSite(_T("http://agender.sourceforge.net"),_("Agender Web Site"));
 	info.SetLicence(_("Agender is free software; you can redistribute it and/or modify\n"
 				"it under the terms of the GNU General Public License as published by\n"
@@ -262,9 +235,16 @@ void AgenderFrame::OnButton3Click(wxCommandEvent& WXUNUSED(event))
 				"\n"
 				"You should have received a copy of the GNU General Public License\n"
 				"along with Agender. If not, see <http://www.gnu.org/licenses/>."));
-	info.SetVersion(_T(__AGENDER_VERSION__));
+	info.SetVersion(__AGENDER_VERSION__);
 	info.SetCopyright(_T("Copyright (C) 2009-2010 Gabriel Espinoza"));
-	info.SetIcon(agender_xpm);
+	wxIcon ico;
+	{
+		wxFileName icoFile;
+		icoFile.AssignDir(wxStandardPaths::Get().GetResourcesDir());
+		icoFile.SetName(_T("agender48.png"));
+		ico.CopyFromBitmap(wxBitmap(icoFile.GetFullPath()));
+	}
+	info.SetIcon(ico);
 	wxAboutBox(info);
 }
 
@@ -414,128 +394,6 @@ void AgenderFrame::ChangeSelector()
 	MarkDays();
 }
 
-void AgenderFrame::OnAutoStart(wxCommandEvent& WXUNUSED(event))
-{
-#if defined __UNIX__ && !defined __APPLE__ //should i simply use __LINUX__ || __BSD__ ? and maybe __SOLARIS__
-	//we use freedestop.org standard
-	wxFileName desktopFname;
-	desktopFname.AssignDir(wxGetHomeDir());
-	desktopFname.AppendDir(_T(".config"));
-	desktopFname.AppendDir(_T("autostart"));
-	desktopFname.SetName(_T("Agender"));
-	desktopFname.SetExt(_T("desktop"));
-	wxString desktopFile = desktopFname.GetFullPath();
-	//fluxbox startup script
-	wxFileName fluxFname;
-	fluxFname.AssignDir(wxGetHomeDir());
-	fluxFname.AppendDir(_T(".fluxbox"));
-	fluxFname.SetName(_T("startup"));
-	wxString  fluxFile= fluxFname.GetFullPath();
-	//existance!
-	if (!wxDirExists(desktopFname.GetPath()) && !wxFileExists(fluxFile))
-	{
-		wxMessageBox(_("AutoStart is only available under Windows, Fluxbox "
-				   " and Unix desktops that follow the freedesktop.org standards. "//how sadly! =(
-				   "If you add support for any other system, please send patches "
-				   "to the patch tracker in the Agender project page at "
-				   "http://sourceforge.net/projects/agender/ or you can also help "
-				   "donating hardware that runs your favorite system."));
-		return;
-	}
-#elif defined __WXMSW__
-	//we use the windows registry
-	wxRegKey key;
-	key.SetName(_T("HKEY_CURRENT_USER\\Software\\Microsoft\\Windows\\CurrentVersion\\Run"));
-#else //__WXOSX__ || __WXMAC__
-	//we ask for help :)
-	wxMessageBox(_("AutoStart is only available under Windows, Fluxbox "
-			   " and Unix desktops that follow the freedesktop.org standards. "//how sadly! =(
-			   "If you add support for any other system, please send patches "
-			   "to the patch tracker in the Agender project page at "
-			   "http://sourceforge.net/projects/agender/ or you can also help "
-			   "donating hardware that runs your favorite system."));
-	return;
-#endif
-	//add or remove
-	bool autostart=false;
-	wxConfig::Get()->Read(_T("/autostart"),&autostart,false);
-	if (autostart)
-	{
-		///add
-#if defined __UNIX__ && !defined __APPLE__
-		//freedesktop.org
-		if (!wxFileExists(desktopFile))
-		{
-			//lets use the easyest way
-			wxTextFile desktop;
-			desktop.Create(desktopFile);
-			desktop.AddLine(_T("[Desktop Entry]"));
-			desktop.AddLine(_T("Type=Application"));
-			desktop.AddLine(_T("Name=Agender"));
-			desktop.AddLine(_T("Exec=Agender"));
-			desktop.AddLine(_T("Icon=Agender"));
-			desktop.Write(wxTextFileType_Unix);//needed?
-			desktop.Close();
-		}
-		//add a command to run Agender to the fluxbox  startup script
-		wxTextFile startflux;
-		if (startflux.Open(fluxFile))
-		{
-			wxString command;
-			int indx = -1;
-			bool alreadyThere = false;
-			for (command = startflux.GetLastLine(); startflux.GetCurrentLine() > 0;
-					command = startflux.GetPrevLine())
-			{
-				if (command.Matches(_T("exec*fluxbox*")))
-					indx = startflux.GetCurrentLine();
-				if (command.Matches(_T("Agender &")))
-					alreadyThere = true;
-			}
-			if (indx > -1 && !alreadyThere)
-			{
-				startflux.InsertLine(_T("Agender &"),indx);
-				startflux.Write();
-			}
-			startflux.Close();
-		}
-#elif defined __WXMSW__
-		wxString AgenderValue;
-		key.QueryValue(_T("Agender"),AgenderValue);
-		if (!key.HasValue(_T("Agender")) || AgenderValue != wxStandardPaths::Get().GetExecutablePath())
-			key.SetValue(_T("Agender"),wxStandardPaths::Get().GetExecutablePath());
-#endif
-	}
-	else///remove
-#if defined __UNIX__ && !defined __APPLE__
-	{
-		if (wxFileExists(desktopFile))
-			wxRemoveFile(desktopFile);
-		//clean fluxbox startup script
-		wxTextFile startflux;
-		if (startflux.Open(fluxFile))
-		{
-			wxString command;
-			for (command = startflux.GetLastLine(); startflux.GetCurrentLine() > 0;
-					command = startflux.GetPrevLine())
-			{
-				if (command.Matches(_T("Agender &")))
-				{
-					startflux.RemoveLine(startflux.GetCurrentLine());
-					startflux.Write();
-				}
-			}
-			startflux.Close();
-		}
-	}
-#elif defined __WXMSW__
-		if (key.HasValue(_T("Agender")))
-			key.DeleteValue(_T("Agender"));
-#elif defined __WXOSX__
-	return;
-#endif
-}
-
 void AgenderFrame::OnTextCtrl1Text(wxCommandEvent& WXUNUSED(event))
 {
 	a_cal->SetNoteText(ListBox1->GetStringSelection(),TextCtrl1->GetValue());
@@ -611,3 +469,16 @@ void AgenderFrame::OnEscape(wxCommandEvent& WXUNUSED(event))
 {
 	Close();
 }
+
+void AgenderFrame::OnUpdateFound(wxCommandEvent& event)
+{
+	wxLogVerbose(_T("creating dialog"));
+	wxMessageDialog dlg(wxTheApp->GetTopWindow(),
+			wxString::Format(_("The %s version of %s has been released. "
+				"Do you want to download it?"),event.GetString().c_str(),wxTheApp->GetAppName().c_str()),
+			_("Upgrade Found"),wxYES_NO|wxSTAY_ON_TOP);
+	if (dlg.ShowModal() == wxID_YES)
+	{
+		wxLaunchDefaultBrowser(_T("http://agender.sourceforge.net/index.php?page=Downloads"));
+	}
+}
