@@ -11,12 +11,12 @@
 #include <wx/taskbar.h>
 #include <wx/colour.h>
 #include <wx/frame.h>
+#include "wxAutoStart.h"
 
 class AgenderTray : public wxTaskBarIcon
 {
 	public:
-		AgenderTray(wxFrame* frame,long colalpha);
-
+		AgenderTray(wxFrame* frame);
 		wxMenu* CreatePopupMenu();
 	private:
 		enum
@@ -31,12 +31,27 @@ class AgenderTray : public wxTaskBarIcon
 			ID_SYMBOL,
 			ID_YEARSEL=7003,
 			ID_NOTES_COLOUR=7004,
-			ID_AUTOSTART = 7005
+			ID_AUTOSTART = 7005,
+			ID_NOTIFY,
+			ID_LANG_DEF,
+			ID_LANG_ES,
+			ID_LANG_DE,
+			ID_LANG_JA,
+			ID_LANG_SV,
+			ID_LANG_FR,
+			ID_LANG_PT,
+			ID_LANG_EL,
+			ID_LANG_ZH_HK,
+			ID_LANG_ZH_CN,
+			ID_LANG_HE,
+			ID_LANG_RO,
+			ID_LANG_LAST
 		};
 		wxFrame* frame;
 		int alpha;
 		int opc;
 		wxColour notesColour;
+		AutoStart astart;
 
 		void OnLeft(wxTaskBarIconEvent& event);
 		void OnMenuShow(wxCommandEvent& event);
@@ -48,6 +63,8 @@ class AgenderTray : public wxTaskBarIcon
 		void OnMenuFind(wxCommandEvent& event);
 		void OnMenuAutoStart(wxCommandEvent& event);
 		void OnMenuSymbols(wxCommandEvent& event);
+		void OnMenuNotify(wxCommandEvent& event);
+		void OnMenuLang(wxCommandEvent& event);
 
 		DECLARE_EVENT_TABLE()
 };
